Class: Fastly::ApisecurityOperationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/apisecurity_operations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ApisecurityOperationsApi

Returns a new instance of ApisecurityOperationsApi.



17
18
19
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#api_security_create_operation(opts = {}) ⇒ OperationGet

Create operation Create a new operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_create (OperationCreate)

Returns:



25
26
27
28
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 25

def api_security_create_operation(opts = {})
  data, _status_code, _headers = api_security_create_operation_with_http_info(opts)
  data
end

#api_security_create_operation_tag(opts = {}) ⇒ TagGet

Create operation tag Create a new operation tag associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_create (TagCreate)

Returns:



95
96
97
98
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 95

def api_security_create_operation_tag(opts = {})
  data, _status_code, _headers = api_security_create_operation_tag_with_http_info(opts)
  data
end

#api_security_create_operation_tag_with_http_info(opts = {}) ⇒ Array<(TagGet, Integer, Hash)>

Create operation tag Create a new operation tag associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_create (TagCreate)

Returns:

  • (Array<(TagGet, Integer, Hash)>)

    TagGet data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 105

def api_security_create_operation_tag_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_create_operation_tag ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_create_operation_tag"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/tags'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'tag_create'])

  # return_type
  return_type = opts[:debug_return_type] || 'TagGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_create_operation_tag",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_create_operation_tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_create_operation_with_http_info(opts = {}) ⇒ Array<(OperationGet, Integer, Hash)>

Create operation Create a new operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_create (OperationCreate)

Returns:

  • (Array<(OperationGet, Integer, Hash)>)

    OperationGet data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 35

def api_security_create_operation_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_create_operation ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_create_operation"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/operations'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'operation_create'])

  # return_type
  return_type = opts[:debug_return_type] || 'OperationGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_create_operation",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_create_operation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_delete_operation(opts = {}) ⇒ nil

Delete operation Delete an existing operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

Returns:

  • (nil)


165
166
167
168
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 165

def api_security_delete_operation(opts = {})
  api_security_delete_operation_with_http_info(opts)
  nil
end

#api_security_delete_operation_tag(opts = {}) ⇒ nil

Delete operation tag Delete an existing operation tag.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

Returns:

  • (nil)


235
236
237
238
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 235

def api_security_delete_operation_tag(opts = {})
  api_security_delete_operation_tag_with_http_info(opts)
  nil
end

#api_security_delete_operation_tag_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete operation tag Delete an existing operation tag.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 245

def api_security_delete_operation_tag_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_delete_operation_tag ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  tag_id = opts[:'tag_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_delete_operation_tag"
  end
  # verify the required parameter 'tag_id' is set
  if @api_client.config.client_side_validation && tag_id.nil?
    fail ArgumentError, "Missing the required parameter 'tag_id' when calling ApisecurityOperationsApi.api_security_delete_operation_tag"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/tags/{tag_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'tag_id' + '}', CGI.escape(tag_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_delete_operation_tag",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_delete_operation_tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_delete_operation_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete operation Delete an existing operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 175

def api_security_delete_operation_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_delete_operation ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  operation_id = opts[:'operation_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_delete_operation"
  end
  # verify the required parameter 'operation_id' is set
  if @api_client.config.client_side_validation && operation_id.nil?
    fail ArgumentError, "Missing the required parameter 'operation_id' when calling ApisecurityOperationsApi.api_security_delete_operation"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/operations/{operation_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'operation_id' + '}', CGI.escape(operation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_delete_operation",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_delete_operation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_get_operation(opts = {}) ⇒ OperationGet

Retrieve operation Get a specific operation associated with a service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

Returns:



305
306
307
308
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 305

def api_security_get_operation(opts = {})
  data, _status_code, _headers = api_security_get_operation_with_http_info(opts)
  data
end

#api_security_get_operation_tag(opts = {}) ⇒ TagGet

Retrieve operation tag Get a specific operation tag by its unique identifier.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

Returns:



375
376
377
378
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 375

def api_security_get_operation_tag(opts = {})
  data, _status_code, _headers = api_security_get_operation_tag_with_http_info(opts)
  data
end

#api_security_get_operation_tag_with_http_info(opts = {}) ⇒ Array<(TagGet, Integer, Hash)>

Retrieve operation tag Get a specific operation tag by its unique identifier.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

Returns:

  • (Array<(TagGet, Integer, Hash)>)

    TagGet data, response status code and response headers



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 385

def api_security_get_operation_tag_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_get_operation_tag ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  tag_id = opts[:'tag_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_get_operation_tag"
  end
  # verify the required parameter 'tag_id' is set
  if @api_client.config.client_side_validation && tag_id.nil?
    fail ArgumentError, "Missing the required parameter 'tag_id' when calling ApisecurityOperationsApi.api_security_get_operation_tag"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/tags/{tag_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'tag_id' + '}', CGI.escape(tag_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TagGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_get_operation_tag",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_get_operation_tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_get_operation_with_http_info(opts = {}) ⇒ Array<(OperationGet, Integer, Hash)>

Retrieve operation Get a specific operation associated with a service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

Returns:

  • (Array<(OperationGet, Integer, Hash)>)

    OperationGet data, response status code and response headers



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 315

def api_security_get_operation_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_get_operation ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  operation_id = opts[:'operation_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_get_operation"
  end
  # verify the required parameter 'operation_id' is set
  if @api_client.config.client_side_validation && operation_id.nil?
    fail ArgumentError, "Missing the required parameter 'operation_id' when calling ApisecurityOperationsApi.api_security_get_operation"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/operations/{operation_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'operation_id' + '}', CGI.escape(operation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'OperationGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_get_operation",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_get_operation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_list_discovered_operations(opts = {}) ⇒ InlineResponse2001

List discovered operations List all discovered operations associated with a specific service. Optionally filter operations by status.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :status (String)

    Filter operations by status. Only operations with this status will be returned.

  • :limit (Integer)

    The maximum number of operations to return per page. (default to 100)

  • :page (Integer)

    The page number to return. (default to 0)

Returns:



447
448
449
450
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 447

def api_security_list_discovered_operations(opts = {})
  data, _status_code, _headers = api_security_list_discovered_operations_with_http_info(opts)
  data
end

#api_security_list_discovered_operations_with_http_info(opts = {}) ⇒ Array<(InlineResponse2001, Integer, Hash)>

List discovered operations List all discovered operations associated with a specific service. Optionally filter operations by status.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :status (String)

    Filter operations by status. Only operations with this status will be returned.

  • :limit (Integer)

    The maximum number of operations to return per page. (default to 100)

  • :page (Integer)

    The page number to return. (default to 0)

Returns:

  • (Array<(InlineResponse2001, Integer, Hash)>)

    InlineResponse2001 data, response status code and response headers



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 459

def api_security_list_discovered_operations_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_list_discovered_operations ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_list_discovered_operations"
  end
  allowable_values = ["DISCOVERED", "SAVED", "IGNORED"]
  if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status'])
    fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ApisecurityOperationsApi.api_security_list_discovered_operations, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ApisecurityOperationsApi.api_security_list_discovered_operations, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ApisecurityOperationsApi.api_security_list_discovered_operations, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/discovered-operations'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InlineResponse2001'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_list_discovered_operations",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_list_discovered_operations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_list_operation_tags(opts = {}) ⇒ InlineResponse2003

List operation tags List all operation tags associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

Returns:



532
533
534
535
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 532

def api_security_list_operation_tags(opts = {})
  data, _status_code, _headers = api_security_list_operation_tags_with_http_info(opts)
  data
end

#api_security_list_operation_tags_with_http_info(opts = {}) ⇒ Array<(InlineResponse2003, Integer, Hash)>

List operation tags List all operation tags associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

Returns:

  • (Array<(InlineResponse2003, Integer, Hash)>)

    InlineResponse2003 data, response status code and response headers



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 541

def api_security_list_operation_tags_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_list_operation_tags ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_list_operation_tags"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/tags'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InlineResponse2003'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_list_operation_tags",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_list_operation_tags\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_list_operations(opts = {}) ⇒ InlineResponse2002

List operations List all operations associated with a specific service. Optionally filter operations by tag ID.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    Filter operations by operation tag ID. Only operations associated with this operation tag will be returned.

  • :limit (Integer)

    The maximum number of operations to return per page. (default to 100)

  • :page (Integer)

    The page number to return. (default to 0)

Returns:



598
599
600
601
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 598

def api_security_list_operations(opts = {})
  data, _status_code, _headers = api_security_list_operations_with_http_info(opts)
  data
end

#api_security_list_operations_with_http_info(opts = {}) ⇒ Array<(InlineResponse2002, Integer, Hash)>

List operations List all operations associated with a specific service. Optionally filter operations by tag ID.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    Filter operations by operation tag ID. Only operations associated with this operation tag will be returned.

  • :limit (Integer)

    The maximum number of operations to return per page. (default to 100)

  • :page (Integer)

    The page number to return. (default to 0)

Returns:

  • (Array<(InlineResponse2002, Integer, Hash)>)

    InlineResponse2002 data, response status code and response headers



610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 610

def api_security_list_operations_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_list_operations ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_list_operations"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ApisecurityOperationsApi.api_security_list_operations, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ApisecurityOperationsApi.api_security_list_operations, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ApisecurityOperationsApi.api_security_list_operations, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/operations'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'tag_id'] = opts[:'tag_id'] if !opts[:'tag_id'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InlineResponse2002'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_list_operations",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_list_operations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_update_operation(opts = {}) ⇒ OperationGet

Update operation Partially update an existing operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

  • :operation_update (OperationUpdate)

Returns:



681
682
683
684
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 681

def api_security_update_operation(opts = {})
  data, _status_code, _headers = api_security_update_operation_with_http_info(opts)
  data
end

#api_security_update_operation_tag(opts = {}) ⇒ TagGet

Update operation tag Partially update an existing operation tag.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

  • :body (TagBase)

Returns:



758
759
760
761
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 758

def api_security_update_operation_tag(opts = {})
  data, _status_code, _headers = api_security_update_operation_tag_with_http_info(opts)
  data
end

#api_security_update_operation_tag_with_http_info(opts = {}) ⇒ Array<(TagGet, Integer, Hash)>

Update operation tag Partially update an existing operation tag.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :tag_id (String)

    The unique identifier of the operation tag. (required)

  • :body (TagBase)

Returns:

  • (Array<(TagGet, Integer, Hash)>)

    TagGet data, response status code and response headers



769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 769

def api_security_update_operation_tag_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_update_operation_tag ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  tag_id = opts[:'tag_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_update_operation_tag"
  end
  # verify the required parameter 'tag_id' is set
  if @api_client.config.client_side_validation && tag_id.nil?
    fail ArgumentError, "Missing the required parameter 'tag_id' when calling ApisecurityOperationsApi.api_security_update_operation_tag"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/tags/{tag_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'tag_id' + '}', CGI.escape(tag_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'body'])

  # return_type
  return_type = opts[:debug_return_type] || 'TagGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_update_operation_tag",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_update_operation_tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_security_update_operation_with_http_info(opts = {}) ⇒ Array<(OperationGet, Integer, Hash)>

Update operation Partially update an existing operation associated with a specific service.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    The unique identifier of the service. (required)

  • :operation_id (String)

    The unique identifier of the operation. (required)

  • :operation_update (OperationUpdate)

Returns:

  • (Array<(OperationGet, Integer, Hash)>)

    OperationGet data, response status code and response headers



692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
# File 'lib/fastly/api/apisecurity_operations_api.rb', line 692

def api_security_update_operation_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApisecurityOperationsApi.api_security_update_operation ...'
  end
  # unbox the parameters from the hash
  service_id = opts[:'service_id']
  operation_id = opts[:'operation_id']
  # verify the required parameter 'service_id' is set
  if @api_client.config.client_side_validation && service_id.nil?
    fail ArgumentError, "Missing the required parameter 'service_id' when calling ApisecurityOperationsApi.api_security_update_operation"
  end
  # verify the required parameter 'operation_id' is set
  if @api_client.config.client_side_validation && operation_id.nil?
    fail ArgumentError, "Missing the required parameter 'operation_id' when calling ApisecurityOperationsApi.api_security_update_operation"
  end
  # resource path
  local_var_path = '/api-security/v1/services/{service_id}/operations/{operation_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'operation_id' + '}', CGI.escape(operation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'operation_update'])

  # return_type
  return_type = opts[:debug_return_type] || 'OperationGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"ApisecurityOperationsApi.api_security_update_operation",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApisecurityOperationsApi#api_security_update_operation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end