Class: Fastly::DomainApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/domain_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DomainApi

Returns a new instance of DomainApi.



17
18
19
# File 'lib/fastly/api/domain_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/domain_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#check_domain(opts = {}) ⇒ Array<Object>

Validate DNS configuration for a single domain on a service Checks the status of a specific domain's DNS record for a Service Version. Returns an array in the same format as domain/check_all.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    Alphanumeric string identifying the service. (required)

  • :version_id (Integer)

    Integer identifying a service version. (required)

  • :domain_name (String)

    The name of the domain or domains associated with this service. (required)

Returns:

  • (Array<Object>)


26
27
28
29
# File 'lib/fastly/api/domain_api.rb', line 26

def check_domain(opts = {})
  data, _status_code, _headers = check_domain_with_http_info(opts)
  data
end

#check_domain_with_http_info(opts = {}) ⇒ Array<(Array<Object>, Integer, Hash)>

Validate DNS configuration for a single domain on a service Checks the status of a specific domain's DNS record for a Service Version. Returns an array in the same format as domain/check_all.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :service_id (String)

    Alphanumeric string identifying the service. (required)

  • :version_id (Integer)

    Integer identifying a service version. (required)

  • :domain_name (String)

    The name of the domain or domains associated with this service. (required)

Returns:

  • (Array<(Array<Object>, Integer, Hash)>)

    Array data, response status code and response headers

    
    
    37
    38
    39
    40
    41
    42
    43
    44
    45
    46
    47
    48
    49
    50
    51
    52
    53
    54
    55
    56
    57
    58
    59
    60
    61
    62
    63
    64
    65
    66
    67
    68
    69
    70
    71
    72
    73
    74
    75
    76
    77
    78
    79
    80
    81
    82
    83
    84
    85
    86
    87
    88
    89
    90
    91
    92
    93
    94
    95
    # File 'lib/fastly/api/domain_api.rb', line 37
    
    def check_domain_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.check_domain ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      domain_name = opts[:'domain_name']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.check_domain"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.check_domain"
      end
      # verify the required parameter 'domain_name' is set
      if @api_client.config.client_side_validation && domain_name.nil?
        fail ArgumentError, "Missing the required parameter 'domain_name' when calling DomainApi.check_domain"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain/{domain_name}/check'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s)).sub('{' + 'domain_name' + '}', CGI.escape(domain_name.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<Object>'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.check_domain",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#check_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #check_domains(opts = {}) ⇒ Array<Array>

    Validate DNS configuration for all domains on a service Checks the status of all domains' DNS records for a Service Version. Returns an array of 3 items for each domain; the first is the details for the domain, the second is the current CNAME of the domain, and the third is a boolean indicating whether or not it has been properly setup to use Fastly.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    Returns:

    • (Array<Array>)
    
    
    102
    103
    104
    105
    # File 'lib/fastly/api/domain_api.rb', line 102
    
    def check_domains(opts = {})
      data, _status_code, _headers = check_domains_with_http_info(opts)
      data
    end

    #check_domains_with_http_info(opts = {}) ⇒ Array<(Array<Array>, Integer, Hash)>

    Validate DNS configuration for all domains on a service Checks the status of all domains' DNS records for a Service Version. Returns an array of 3 items for each domain; the first is the details for the domain, the second is the current CNAME of the domain, and the third is a boolean indicating whether or not it has been properly setup to use Fastly.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    Returns:

    • (Array<(Array<Array>, Integer, Hash)>)

      Array data, response status code and response headers

    
    
    112
    113
    114
    115
    116
    117
    118
    119
    120
    121
    122
    123
    124
    125
    126
    127
    128
    129
    130
    131
    132
    133
    134
    135
    136
    137
    138
    139
    140
    141
    142
    143
    144
    145
    146
    147
    148
    149
    150
    151
    152
    153
    154
    155
    156
    157
    158
    159
    160
    161
    162
    163
    164
    165
    # File 'lib/fastly/api/domain_api.rb', line 112
    
    def check_domains_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.check_domains ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.check_domains"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.check_domains"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain/check_all'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<Array>'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.check_domains",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#check_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #create_domain(opts = {}) ⇒ DomainResponse

    Add a domain name to a service Create a domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :comment (String)

      A freeform descriptive note.

    • :name (String)

      The name of the domain or domains associated with this service.

    Returns:

    
    
    174
    175
    176
    177
    # File 'lib/fastly/api/domain_api.rb', line 174
    
    def create_domain(opts = {})
      data, _status_code, _headers = create_domain_with_http_info(opts)
      data
    end

    #create_domain_with_http_info(opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>

    Add a domain name to a service Create a domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :comment (String)

      A freeform descriptive note.

    • :name (String)

      The name of the domain or domains associated with this service.

    Returns:

    • (Array<(DomainResponse, Integer, Hash)>)

      DomainResponse data, response status code and response headers

    
    
    186
    187
    188
    189
    190
    191
    192
    193
    194
    195
    196
    197
    198
    199
    200
    201
    202
    203
    204
    205
    206
    207
    208
    209
    210
    211
    212
    213
    214
    215
    216
    217
    218
    219
    220
    221
    222
    223
    224
    225
    226
    227
    228
    229
    230
    231
    232
    233
    234
    235
    236
    237
    238
    239
    240
    241
    242
    243
    244
    245
    246
    # File 'lib/fastly/api/domain_api.rb', line 186
    
    def create_domain_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.create_domain ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.create_domain"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.create_domain"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])
      if !content_type.nil?
          header_params['Content-Type'] = content_type
      end
    
      # form parameters
      form_params = opts[:form_params] || {}
      form_params['comment'] = opts[:'comment'] if !opts[:'comment'].nil?
      form_params['name'] = opts[:'name'] if !opts[:'name'].nil?
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'DomainResponse'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.create_domain",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#create_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #delete_domain(opts = {}) ⇒ InlineResponse200

    Remove a domain from a service Delete the domain for a particular service and versions.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    Returns:

    
    
    254
    255
    256
    257
    # File 'lib/fastly/api/domain_api.rb', line 254
    
    def delete_domain(opts = {})
      data, _status_code, _headers = delete_domain_with_http_info(opts)
      data
    end

    #delete_domain_with_http_info(opts = {}) ⇒ Array<(InlineResponse200, Integer, Hash)>

    Remove a domain from a service Delete the domain for a particular service and versions.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    Returns:

    • (Array<(InlineResponse200, Integer, Hash)>)

      InlineResponse200 data, response status code and response headers

    
    
    265
    266
    267
    268
    269
    270
    271
    272
    273
    274
    275
    276
    277
    278
    279
    280
    281
    282
    283
    284
    285
    286
    287
    288
    289
    290
    291
    292
    293
    294
    295
    296
    297
    298
    299
    300
    301
    302
    303
    304
    305
    306
    307
    308
    309
    310
    311
    312
    313
    314
    315
    316
    317
    318
    319
    320
    321
    322
    323
    # File 'lib/fastly/api/domain_api.rb', line 265
    
    def delete_domain_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.delete_domain ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      domain_name = opts[:'domain_name']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.delete_domain"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.delete_domain"
      end
      # verify the required parameter 'domain_name' is set
      if @api_client.config.client_side_validation && domain_name.nil?
        fail ArgumentError, "Missing the required parameter 'domain_name' when calling DomainApi.delete_domain"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain/{domain_name}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s)).sub('{' + 'domain_name' + '}', CGI.escape(domain_name.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'InlineResponse200'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.delete_domain",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#delete_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #get_domain(opts = {}) ⇒ DomainResponse

    Describe a domain Get the domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    Returns:

    
    
    331
    332
    333
    334
    # File 'lib/fastly/api/domain_api.rb', line 331
    
    def get_domain(opts = {})
      data, _status_code, _headers = get_domain_with_http_info(opts)
      data
    end

    #get_domain_with_http_info(opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>

    Describe a domain Get the domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    Returns:

    • (Array<(DomainResponse, Integer, Hash)>)

      DomainResponse data, response status code and response headers

    
    
    342
    343
    344
    345
    346
    347
    348
    349
    350
    351
    352
    353
    354
    355
    356
    357
    358
    359
    360
    361
    362
    363
    364
    365
    366
    367
    368
    369
    370
    371
    372
    373
    374
    375
    376
    377
    378
    379
    380
    381
    382
    383
    384
    385
    386
    387
    388
    389
    390
    391
    392
    393
    394
    395
    396
    397
    398
    399
    400
    # File 'lib/fastly/api/domain_api.rb', line 342
    
    def get_domain_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.get_domain ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      domain_name = opts[:'domain_name']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.get_domain"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.get_domain"
      end
      # verify the required parameter 'domain_name' is set
      if @api_client.config.client_side_validation && domain_name.nil?
        fail ArgumentError, "Missing the required parameter 'domain_name' when calling DomainApi.get_domain"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain/{domain_name}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s)).sub('{' + 'domain_name' + '}', CGI.escape(domain_name.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'DomainResponse'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.get_domain",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#get_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #list_domains(opts = {}) ⇒ Array<DomainResponse>

    List domains List all the domains for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    Returns:

    
    
    407
    408
    409
    410
    # File 'lib/fastly/api/domain_api.rb', line 407
    
    def list_domains(opts = {})
      data, _status_code, _headers = list_domains_with_http_info(opts)
      data
    end

    #list_domains_with_http_info(opts = {}) ⇒ Array<(Array<DomainResponse>, Integer, Hash)>

    List domains List all the domains for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    Returns:

    • (Array<(Array<DomainResponse>, Integer, Hash)>)

      Array data, response status code and response headers

    
    
    417
    418
    419
    420
    421
    422
    423
    424
    425
    426
    427
    428
    429
    430
    431
    432
    433
    434
    435
    436
    437
    438
    439
    440
    441
    442
    443
    444
    445
    446
    447
    448
    449
    450
    451
    452
    453
    454
    455
    456
    457
    458
    459
    460
    461
    462
    463
    464
    465
    466
    467
    468
    469
    470
    # File 'lib/fastly/api/domain_api.rb', line 417
    
    def list_domains_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.list_domains ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.list_domains"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.list_domains"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<DomainResponse>'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.list_domains",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#list_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #update_domain(opts = {}) ⇒ DomainResponse

    Update a domain Update the domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    • :comment (String)

      A freeform descriptive note.

    • :name (String)

      The name of the domain or domains associated with this service.

    Returns:

    
    
    480
    481
    482
    483
    # File 'lib/fastly/api/domain_api.rb', line 480
    
    def update_domain(opts = {})
      data, _status_code, _headers = update_domain_with_http_info(opts)
      data
    end

    #update_domain_with_http_info(opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>

    Update a domain Update the domain for a particular service and version.

    Parameters:

    • opts (Hash) (defaults to: {})

      a customizable set of options

    Options Hash (opts):

    • :service_id (String)

      Alphanumeric string identifying the service. (required)

    • :version_id (Integer)

      Integer identifying a service version. (required)

    • :domain_name (String)

      The name of the domain or domains associated with this service. (required)

    • :comment (String)

      A freeform descriptive note.

    • :name (String)

      The name of the domain or domains associated with this service.

    Returns:

    • (Array<(DomainResponse, Integer, Hash)>)

      DomainResponse data, response status code and response headers

    
    
    493
    494
    495
    496
    497
    498
    499
    500
    501
    502
    503
    504
    505
    506
    507
    508
    509
    510
    511
    512
    513
    514
    515
    516
    517
    518
    519
    520
    521
    522
    523
    524
    525
    526
    527
    528
    529
    530
    531
    532
    533
    534
    535
    536
    537
    538
    539
    540
    541
    542
    543
    544
    545
    546
    547
    548
    549
    550
    551
    552
    553
    554
    555
    556
    557
    558
    # File 'lib/fastly/api/domain_api.rb', line 493
    
    def update_domain_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: DomainApi.update_domain ...'
      end
      # unbox the parameters from the hash
      service_id = opts[:'service_id']
      version_id = opts[:'version_id']
      domain_name = opts[:'domain_name']
      # verify the required parameter 'service_id' is set
      if @api_client.config.client_side_validation && service_id.nil?
        fail ArgumentError, "Missing the required parameter 'service_id' when calling DomainApi.update_domain"
      end
      # verify the required parameter 'version_id' is set
      if @api_client.config.client_side_validation && version_id.nil?
        fail ArgumentError, "Missing the required parameter 'version_id' when calling DomainApi.update_domain"
      end
      # verify the required parameter 'domain_name' is set
      if @api_client.config.client_side_validation && domain_name.nil?
        fail ArgumentError, "Missing the required parameter 'domain_name' when calling DomainApi.update_domain"
      end
      # resource path
      local_var_path = '/service/{service_id}/version/{version_id}/domain/{domain_name}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'version_id' + '}', CGI.escape(version_id.to_s)).sub('{' + 'domain_name' + '}', CGI.escape(domain_name.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])
      if !content_type.nil?
          header_params['Content-Type'] = content_type
      end
    
      # form parameters
      form_params = opts[:form_params] || {}
      form_params['comment'] = opts[:'comment'] if !opts[:'comment'].nil?
      form_params['name'] = opts[:'name'] if !opts[:'name'].nil?
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'DomainResponse'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['token']
    
      new_options = opts.merge(
        :operation => :"DomainApi.update_domain",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: DomainApi#update_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end