Class: Fastly::DomainResearchApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/domain_research_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DomainResearchApi



17
18
19
# File 'lib/fastly/api/domain_research_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/domain_research_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#domain_status(opts = {}) ⇒ Status

Domain status The Status method checks the availability status of a single domain name.

Options Hash (opts):

  • :domain (String) — default: required
  • :scope (String)


25
26
27
28
# File 'lib/fastly/api/domain_research_api.rb', line 25

def domain_status(opts = {})
  data, _status_code, _headers = domain_status_with_http_info(opts)
  data
end

#domain_status_with_http_info(opts = {}) ⇒ Array<(Status, Integer, Hash)>

Domain status The `Status` method checks the availability status of a single domain name.

Options Hash (opts):

  • :domain (String) — default: required
  • :scope (String)


35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/fastly/api/domain_research_api.rb', line 35

def domain_status_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DomainResearchApi.domain_status ...'
  end
  # unbox the parameters from the hash
  domain = opts[:'domain']
  # verify the required parameter 'domain' is set
  if @api_client.config.client_side_validation && domain.nil?
    fail ArgumentError, "Missing the required parameter 'domain' when calling DomainResearchApi.domain_status"
  end
  # resource path
  local_var_path = '/domain-management/v1/tools/status'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'domain'] = domain
  query_params[:'scope'] = opts[:'scope'] if !opts[:'scope'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Status'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"DomainResearchApi.domain_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DomainResearchApi#domain_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#suggest_domains(opts = {}) ⇒ InlineResponse20016

Suggest domains The Suggest method performs a real-time query of the search term(s) against the known zone database, making recommendations, stemming, and applying Unicode folding, IDN normalization, registrar supported-zone restrictions, and other refinements. Note: Suggest method responses do not include domain availability status.

Options Hash (opts):

  • :query (String) — default: required
  • :defaults (String)
  • :keywords (String)
  • :location (String)
  • :vendor (String)


95
96
97
98
# File 'lib/fastly/api/domain_research_api.rb', line 95

def suggest_domains(opts = {})
  data, _status_code, _headers = suggest_domains_with_http_info(opts)
  data
end

#suggest_domains_with_http_info(opts = {}) ⇒ Array<(InlineResponse20016, Integer, Hash)>

Suggest domains The `Suggest` method performs a real-time query of the search term(s) against the known zone database, making recommendations, stemming, and applying Unicode folding, IDN normalization, registrar supported-zone restrictions, and other refinements. Note: `Suggest` method responses do not include domain availability status.

Options Hash (opts):

  • :query (String) — default: required
  • :defaults (String)
  • :keywords (String)
  • :location (String)
  • :vendor (String)


108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/fastly/api/domain_research_api.rb', line 108

def suggest_domains_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DomainResearchApi.suggest_domains ...'
  end
  # unbox the parameters from the hash
  query = opts[:'query']
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling DomainResearchApi.suggest_domains"
  end
  # resource path
  local_var_path = '/domain-management/v1/tools/suggest'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'defaults'] = opts[:'defaults'] if !opts[:'defaults'].nil?
  query_params[:'keywords'] = opts[:'keywords'] if !opts[:'keywords'].nil?
  query_params[:'location'] = opts[:'location'] if !opts[:'location'].nil?
  query_params[:'vendor'] = opts[:'vendor'] if !opts[:'vendor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InlineResponse20016'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"DomainResearchApi.suggest_domains",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DomainResearchApi#suggest_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end