Class: Fastly::HealthcheckResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/models/healthcheck_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HealthcheckResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/fastly/models/healthcheck_response.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Fastly::HealthcheckResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Fastly::HealthcheckResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'check_interval')
    self.check_interval = attributes[:'check_interval']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'expected_response')
    self.expected_response = attributes[:'expected_response']
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'http_version')
    self.http_version = attributes[:'http_version']
  end

  if attributes.key?(:'initial')
    self.initial = attributes[:'initial']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'threshold')
    self.threshold = attributes[:'threshold']
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end

  if attributes.key?(:'window')
    self.window = attributes[:'window']
  end

  if attributes.key?(:'service_id')
    self.service_id = attributes[:'service_id']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#check_intervalObject

How often to run the health check in milliseconds. Minimum 1 second, maximum 1 hour.



17
18
19
# File 'lib/fastly/models/healthcheck_response.rb', line 17

def check_interval
  @check_interval
end

#commentObject

A freeform descriptive note.



20
21
22
# File 'lib/fastly/models/healthcheck_response.rb', line 20

def comment
  @comment
end

#created_atObject

Date and time in ISO 8601 format.



60
61
62
# File 'lib/fastly/models/healthcheck_response.rb', line 60

def created_at
  @created_at
end

#deleted_atObject

Date and time in ISO 8601 format.



63
64
65
# File 'lib/fastly/models/healthcheck_response.rb', line 63

def deleted_at
  @deleted_at
end

#expected_responseObject

The status code expected from the host.



23
24
25
# File 'lib/fastly/models/healthcheck_response.rb', line 23

def expected_response
  @expected_response
end

#headersObject

Array of custom headers that will be added to the health check probes.



26
27
28
# File 'lib/fastly/models/healthcheck_response.rb', line 26

def headers
  @headers
end

#hostObject

Which host to check.



29
30
31
# File 'lib/fastly/models/healthcheck_response.rb', line 29

def host
  @host
end

#http_versionObject

Whether to use version 1.0 or 1.1 HTTP.



32
33
34
# File 'lib/fastly/models/healthcheck_response.rb', line 32

def http_version
  @http_version
end

#initialObject

When loading a config, the initial number of probes to be seen as OK.



35
36
37
# File 'lib/fastly/models/healthcheck_response.rb', line 35

def initial
  @initial
end

#methodObject

Which HTTP method to use.



38
39
40
# File 'lib/fastly/models/healthcheck_response.rb', line 38

def method
  @method
end

#nameObject

The name of the health check.



41
42
43
# File 'lib/fastly/models/healthcheck_response.rb', line 41

def name
  @name
end

#pathObject

The path to check.



44
45
46
# File 'lib/fastly/models/healthcheck_response.rb', line 44

def path
  @path
end

#service_idObject

Returns the value of attribute service_id.



55
56
57
# File 'lib/fastly/models/healthcheck_response.rb', line 55

def service_id
  @service_id
end

#thresholdObject

How many health checks must succeed to be considered healthy.



47
48
49
# File 'lib/fastly/models/healthcheck_response.rb', line 47

def threshold
  @threshold
end

#timeoutObject

Timeout in milliseconds.



50
51
52
# File 'lib/fastly/models/healthcheck_response.rb', line 50

def timeout
  @timeout
end

#updated_atObject

Date and time in ISO 8601 format.



66
67
68
# File 'lib/fastly/models/healthcheck_response.rb', line 66

def updated_at
  @updated_at
end

#versionObject

Returns the value of attribute version.



57
58
59
# File 'lib/fastly/models/healthcheck_response.rb', line 57

def version
  @version
end

#windowObject

The number of most recent health check queries to keep for this health check.



53
54
55
# File 'lib/fastly/models/healthcheck_response.rb', line 53

def window
  @window
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/fastly/models/healthcheck_response.rb', line 93

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/fastly/models/healthcheck_response.rb', line 69

def self.attribute_map
  {
    :'check_interval' => :'check_interval',
    :'comment' => :'comment',
    :'expected_response' => :'expected_response',
    :'headers' => :'headers',
    :'host' => :'host',
    :'http_version' => :'http_version',
    :'initial' => :'initial',
    :'method' => :'method',
    :'name' => :'name',
    :'path' => :'path',
    :'threshold' => :'threshold',
    :'timeout' => :'timeout',
    :'window' => :'window',
    :'service_id' => :'service_id',
    :'version' => :'version',
    :'created_at' => :'created_at',
    :'deleted_at' => :'deleted_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
# File 'lib/fastly/models/healthcheck_response.rb', line 307

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.fastly_all_ofObject

List of class defined in allOf (OpenAPI v3)



132
133
134
135
136
137
138
# File 'lib/fastly/models/healthcheck_response.rb', line 132

def self.fastly_all_of
  [
  :'Healthcheck',
  :'ServiceIdAndVersion',
  :'Timestamps'
  ]
end

.fastly_nullableObject

List of attributes with nullable: true



122
123
124
125
126
127
128
129
# File 'lib/fastly/models/healthcheck_response.rb', line 122

def self.fastly_nullable
  Set.new([
    :'comment',
    :'created_at',
    :'deleted_at',
    :'updated_at'
  ])
end

.fastly_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/fastly/models/healthcheck_response.rb', line 98

def self.fastly_types
  {
    :'check_interval' => :'Integer',
    :'comment' => :'String',
    :'expected_response' => :'Integer',
    :'headers' => :'Array<String>',
    :'host' => :'String',
    :'http_version' => :'String',
    :'initial' => :'Integer',
    :'method' => :'String',
    :'name' => :'String',
    :'path' => :'String',
    :'threshold' => :'Integer',
    :'timeout' => :'Integer',
    :'window' => :'Integer',
    :'service_id' => :'String',
    :'version' => :'Integer',
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/fastly/models/healthcheck_response.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      check_interval == o.check_interval &&
      comment == o.comment &&
      expected_response == o.expected_response &&
      headers == o.headers &&
      host == o.host &&
      http_version == o.http_version &&
      initial == o.initial &&
      method == o.method &&
      name == o.name &&
      path == o.path &&
      threshold == o.threshold &&
      timeout == o.timeout &&
      window == o.window &&
      service_id == o.service_id &&
      version == o.version &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/fastly/models/healthcheck_response.rb', line 337

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Fastly.const_get(type)
    klass.respond_to?(:fastly_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/fastly/models/healthcheck_response.rb', line 408

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/fastly/models/healthcheck_response.rb', line 314

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.fastly_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.fastly_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/fastly/models/healthcheck_response.rb', line 294

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



300
301
302
# File 'lib/fastly/models/healthcheck_response.rb', line 300

def hash
  [check_interval, comment, expected_response, headers, host, http_version, initial, method, name, path, threshold, timeout, window, service_id, version, created_at, deleted_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/fastly/models/healthcheck_response.rb', line 232

def list_invalid_properties
  invalid_properties = Array.new
  if !@check_interval.nil? && @check_interval > 3600000
    invalid_properties.push('invalid value for "check_interval", must be smaller than or equal to 3600000.')
  end

  if !@check_interval.nil? && @check_interval < 1000
    invalid_properties.push('invalid value for "check_interval", must be greater than or equal to 1000.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
# File 'lib/fastly/models/healthcheck_response.rb', line 384

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/fastly/models/healthcheck_response.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.fastly_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



378
379
380
# File 'lib/fastly/models/healthcheck_response.rb', line 378

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
# File 'lib/fastly/models/healthcheck_response.rb', line 247

def valid?
  return false if !@check_interval.nil? && @check_interval > 3600000
  return false if !@check_interval.nil? && @check_interval < 1000
  true
end