Class: Fastly::IamRolesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/iam_roles_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ IamRolesApi

Returns a new instance of IamRolesApi.



17
18
19
# File 'lib/fastly/api/iam_roles_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/iam_roles_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#iam_v1_roles_get(opts = {}) ⇒ IamV1RoleResponse

Get IAM role by ID Retrieve a single IAM role by its unique identifier.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :role_id (String)

    Alphanumeric string identifying the role. (required)

  • :include (String)

    Include related data (i.e., permissions).

Returns:



25
26
27
28
# File 'lib/fastly/api/iam_roles_api.rb', line 25

def iam_v1_roles_get(opts = {})
  data, _status_code, _headers = iam_v1_roles_get_with_http_info(opts)
  data
end

#iam_v1_roles_get_with_http_info(opts = {}) ⇒ Array<(IamV1RoleResponse, Integer, Hash)>

Get IAM role by ID Retrieve a single IAM role by its unique identifier.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :role_id (String)

    Alphanumeric string identifying the role. (required)

  • :include (String)

    Include related data (i.e., permissions).

Returns:

  • (Array<(IamV1RoleResponse, Integer, Hash)>)

    IamV1RoleResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fastly/api/iam_roles_api.rb', line 35

def iam_v1_roles_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IamRolesApi.iam_v1_roles_get ...'
  end
  # unbox the parameters from the hash
  role_id = opts[:'role_id']
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling IamRolesApi.iam_v1_roles_get"
  end
  allowable_values = ["permissions"]
  if @api_client.config.client_side_validation && opts[:'include'] && !allowable_values.include?(opts[:'include'])
    fail ArgumentError, "invalid value for \"include\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/iam/v1/roles/{role_id}'.sub('{' + 'role_id' + '}', CGI.escape(role_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IamV1RoleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"IamRolesApi.iam_v1_roles_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IamRolesApi#iam_v1_roles_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#iam_v1_roles_list(opts = {}) ⇒ IamV1RoleListResponse

List IAM roles Retrieve a paginated list of IAM roles available in the account.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :limit (Integer)

    Number of results per page. The maximum is 1000. (default to 100)

  • :cursor (String)

    Cursor value from the &#x60;next_cursor&#x60; field of a previous response, used to retrieve the next page. To request the first page, this should be empty.

Returns:



95
96
97
98
# File 'lib/fastly/api/iam_roles_api.rb', line 95

def iam_v1_roles_list(opts = {})
  data, _status_code, _headers = iam_v1_roles_list_with_http_info(opts)
  data
end

#iam_v1_roles_list_with_http_info(opts = {}) ⇒ Array<(IamV1RoleListResponse, Integer, Hash)>

List IAM roles Retrieve a paginated list of IAM roles available in the account.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :limit (Integer)

    Number of results per page. The maximum is 1000. (default to 100)

  • :cursor (String)

    Cursor value from the &#x60;next_cursor&#x60; field of a previous response, used to retrieve the next page. To request the first page, this should be empty.

Returns:

  • (Array<(IamV1RoleListResponse, Integer, Hash)>)

    IamV1RoleListResponse data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/fastly/api/iam_roles_api.rb', line 105

def iam_v1_roles_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IamRolesApi.iam_v1_roles_list ...'
  end
  # unbox the parameters from the hash
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling IamRolesApi.iam_v1_roles_list, must be smaller than or equal to 1000.'
  end

  # resource path
  local_var_path = '/iam/v1/roles'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IamV1RoleListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"IamRolesApi.iam_v1_roles_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IamRolesApi#iam_v1_roles_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end