Class: Fastly::NgwafAgentKeysApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/ngwaf_agent_keys_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NgwafAgentKeysApi

Returns a new instance of NgwafAgentKeysApi.



17
18
19
# File 'lib/fastly/api/ngwaf_agent_keys_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/ngwaf_agent_keys_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#ngwaf_list_agent_keys(opts = {}) ⇒ InlineResponse20019

List agent keys for a workspace List agent keys for a workspace.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :workspace_id (String)

    The ID of the workspace. (required)

Returns:



24
25
26
27
# File 'lib/fastly/api/ngwaf_agent_keys_api.rb', line 24

def ngwaf_list_agent_keys(opts = {})
  data, _status_code, _headers = ngwaf_list_agent_keys_with_http_info(opts)
  data
end

#ngwaf_list_agent_keys_with_http_info(opts = {}) ⇒ Array<(InlineResponse20019, Integer, Hash)>

List agent keys for a workspace List agent keys for a workspace.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :workspace_id (String)

    The ID of the workspace. (required)

Returns:

  • (Array<(InlineResponse20019, Integer, Hash)>)

    InlineResponse20019 data, response status code and response headers



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/fastly/api/ngwaf_agent_keys_api.rb', line 33

def ngwaf_list_agent_keys_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NgwafAgentKeysApi.ngwaf_list_agent_keys ...'
  end
  # unbox the parameters from the hash
  workspace_id = opts[:'workspace_id']
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling NgwafAgentKeysApi.ngwaf_list_agent_keys"
  end
  # resource path
  local_var_path = '/ngwaf/v1/workspaces/{workspace_id}/agent-keys'.sub('{' + 'workspace_id' + '}', CGI.escape(workspace_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InlineResponse20019'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"NgwafAgentKeysApi.ngwaf_list_agent_keys",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NgwafAgentKeysApi#ngwaf_list_agent_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end