Class: Fastly::NgwafSimulateApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/api/ngwaf_simulate_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NgwafSimulateApi

Returns a new instance of NgwafSimulateApi.



17
18
19
# File 'lib/fastly/api/ngwaf_simulate_api.rb', line 17

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



15
16
17
# File 'lib/fastly/api/ngwaf_simulate_api.rb', line 15

def api_client
  @api_client
end

Instance Method Details

#ngwaf_simulate_waf_request(opts = {}) ⇒ WafSimulateResponse

Simulate a WAF request Simulates a request through the workspace's WAF configuration and returns the WAF response code and any signals that would be detected. The operation is stateless — no simulation data is persisted.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :workspace_id (String)

    The ID of the workspace. (required)

  • :waf_simulate_request (WafSimulateRequest) — default: required

Returns:



25
26
27
28
# File 'lib/fastly/api/ngwaf_simulate_api.rb', line 25

def ngwaf_simulate_waf_request(opts = {})
  data, _status_code, _headers = ngwaf_simulate_waf_request_with_http_info(opts)
  data
end

#ngwaf_simulate_waf_request_with_http_info(opts = {}) ⇒ Array<(WafSimulateResponse, Integer, Hash)>

Simulate a WAF request Simulates a request through the workspace's WAF configuration and returns the WAF response code and any signals that would be detected. The operation is stateless — no simulation data is persisted.

Parameters:

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :workspace_id (String)

    The ID of the workspace. (required)

  • :waf_simulate_request (WafSimulateRequest) — default: required

Returns:

  • (Array<(WafSimulateResponse, Integer, Hash)>)

    WafSimulateResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/fastly/api/ngwaf_simulate_api.rb', line 35

def ngwaf_simulate_waf_request_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NgwafSimulateApi.ngwaf_simulate_waf_request ...'
  end
  # unbox the parameters from the hash
  workspace_id = opts[:'workspace_id']
  waf_simulate_request = opts[:'waf_simulate_request']
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling NgwafSimulateApi.ngwaf_simulate_waf_request"
  end
  # verify the required parameter 'waf_simulate_request' is set
  if @api_client.config.client_side_validation && waf_simulate_request.nil?
    fail ArgumentError, "Missing the required parameter 'waf_simulate_request' when calling NgwafSimulateApi.ngwaf_simulate_waf_request"
  end
  # resource path
  local_var_path = '/ngwaf/v1/workspaces/{workspace_id}/simulate'.sub('{' + 'workspace_id' + '}', CGI.escape(workspace_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(waf_simulate_request)

  # return_type
  return_type = opts[:debug_return_type] || 'WafSimulateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"NgwafSimulateApi.ngwaf_simulate_waf_request",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NgwafSimulateApi#ngwaf_simulate_waf_request\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end