Class: Fastly::PlatformValues
- Inherits:
-
Object
- Object
- Fastly::PlatformValues
- Defined in:
- lib/fastly/models/platform_values.rb
Overview
The results of the query, optionally filtered and grouped over the requested timespan.
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
Timestamp of the metrics data point.
-
#ttfb_edge_p25_us ⇒ Object
25th percentile of time to first byte from edge, in microseconds.
-
#ttfb_edge_p50_us ⇒ Object
50th percentile of time to first byte from edge, in microseconds.
-
#ttfb_edge_p75_us ⇒ Object
75th percentile of time to first byte from edge, in microseconds.
-
#ttfb_edge_p95_us ⇒ Object
95th percentile of time to first byte from edge, in microseconds.
-
#ttfb_edge_p99_us ⇒ Object
99th percentile of time to first byte from edge, in microseconds.
-
#ttfb_origin_p25_us ⇒ Object
25th percentile of time to first byte from origin, in microseconds.
-
#ttfb_origin_p50_us ⇒ Object
50th percentile of time to first byte from origin, in microseconds.
-
#ttfb_origin_p75_us ⇒ Object
75th percentile of time to first byte from origin, in microseconds.
-
#ttfb_origin_p95_us ⇒ Object
95th percentile of time to first byte from origin, in microseconds.
-
#ttfb_origin_p99_us ⇒ Object
99th percentile of time to first byte from origin, in microseconds.
-
#ttfb_shield_p25_us ⇒ Object
25th percentile of time to first byte from shield, in microseconds.
-
#ttfb_shield_p50_us ⇒ Object
50th percentile of time to first byte from shield, in microseconds.
-
#ttfb_shield_p75_us ⇒ Object
75th percentile of time to first byte from shield, in microseconds.
-
#ttfb_shield_p95_us ⇒ Object
95th percentile of time to first byte from shield, in microseconds.
-
#ttfb_shield_p99_us ⇒ Object
99th percentile of time to first byte from shield, in microseconds.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.fastly_nullable ⇒ Object
List of attributes with nullable: true.
-
.fastly_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlatformValues
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PlatformValues
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/fastly/models/platform_values.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Fastly::PlatformValues` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Fastly::PlatformValues`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'ttfb_origin_p25_us') self.ttfb_origin_p25_us = attributes[:'ttfb_origin_p25_us'] end if attributes.key?(:'ttfb_origin_p50_us') self.ttfb_origin_p50_us = attributes[:'ttfb_origin_p50_us'] end if attributes.key?(:'ttfb_origin_p75_us') self.ttfb_origin_p75_us = attributes[:'ttfb_origin_p75_us'] end if attributes.key?(:'ttfb_origin_p95_us') self.ttfb_origin_p95_us = attributes[:'ttfb_origin_p95_us'] end if attributes.key?(:'ttfb_origin_p99_us') self.ttfb_origin_p99_us = attributes[:'ttfb_origin_p99_us'] end if attributes.key?(:'ttfb_shield_p25_us') self.ttfb_shield_p25_us = attributes[:'ttfb_shield_p25_us'] end if attributes.key?(:'ttfb_shield_p50_us') self.ttfb_shield_p50_us = attributes[:'ttfb_shield_p50_us'] end if attributes.key?(:'ttfb_shield_p75_us') self.ttfb_shield_p75_us = attributes[:'ttfb_shield_p75_us'] end if attributes.key?(:'ttfb_shield_p95_us') self.ttfb_shield_p95_us = attributes[:'ttfb_shield_p95_us'] end if attributes.key?(:'ttfb_shield_p99_us') self.ttfb_shield_p99_us = attributes[:'ttfb_shield_p99_us'] end if attributes.key?(:'ttfb_edge_p25_us') self.ttfb_edge_p25_us = attributes[:'ttfb_edge_p25_us'] end if attributes.key?(:'ttfb_edge_p50_us') self.ttfb_edge_p50_us = attributes[:'ttfb_edge_p50_us'] end if attributes.key?(:'ttfb_edge_p75_us') self.ttfb_edge_p75_us = attributes[:'ttfb_edge_p75_us'] end if attributes.key?(:'ttfb_edge_p95_us') self.ttfb_edge_p95_us = attributes[:'ttfb_edge_p95_us'] end if attributes.key?(:'ttfb_edge_p99_us') self.ttfb_edge_p99_us = attributes[:'ttfb_edge_p99_us'] end end |
Instance Attribute Details
#timestamp ⇒ Object
Timestamp of the metrics data point.
18 19 20 |
# File 'lib/fastly/models/platform_values.rb', line 18 def @timestamp end |
#ttfb_edge_p25_us ⇒ Object
25th percentile of time to first byte from edge, in microseconds.
51 52 53 |
# File 'lib/fastly/models/platform_values.rb', line 51 def ttfb_edge_p25_us @ttfb_edge_p25_us end |
#ttfb_edge_p50_us ⇒ Object
50th percentile of time to first byte from edge, in microseconds.
54 55 56 |
# File 'lib/fastly/models/platform_values.rb', line 54 def ttfb_edge_p50_us @ttfb_edge_p50_us end |
#ttfb_edge_p75_us ⇒ Object
75th percentile of time to first byte from edge, in microseconds.
57 58 59 |
# File 'lib/fastly/models/platform_values.rb', line 57 def ttfb_edge_p75_us @ttfb_edge_p75_us end |
#ttfb_edge_p95_us ⇒ Object
95th percentile of time to first byte from edge, in microseconds.
60 61 62 |
# File 'lib/fastly/models/platform_values.rb', line 60 def ttfb_edge_p95_us @ttfb_edge_p95_us end |
#ttfb_edge_p99_us ⇒ Object
99th percentile of time to first byte from edge, in microseconds.
63 64 65 |
# File 'lib/fastly/models/platform_values.rb', line 63 def ttfb_edge_p99_us @ttfb_edge_p99_us end |
#ttfb_origin_p25_us ⇒ Object
25th percentile of time to first byte from origin, in microseconds.
21 22 23 |
# File 'lib/fastly/models/platform_values.rb', line 21 def ttfb_origin_p25_us @ttfb_origin_p25_us end |
#ttfb_origin_p50_us ⇒ Object
50th percentile of time to first byte from origin, in microseconds.
24 25 26 |
# File 'lib/fastly/models/platform_values.rb', line 24 def ttfb_origin_p50_us @ttfb_origin_p50_us end |
#ttfb_origin_p75_us ⇒ Object
75th percentile of time to first byte from origin, in microseconds.
27 28 29 |
# File 'lib/fastly/models/platform_values.rb', line 27 def ttfb_origin_p75_us @ttfb_origin_p75_us end |
#ttfb_origin_p95_us ⇒ Object
95th percentile of time to first byte from origin, in microseconds.
30 31 32 |
# File 'lib/fastly/models/platform_values.rb', line 30 def ttfb_origin_p95_us @ttfb_origin_p95_us end |
#ttfb_origin_p99_us ⇒ Object
99th percentile of time to first byte from origin, in microseconds.
33 34 35 |
# File 'lib/fastly/models/platform_values.rb', line 33 def ttfb_origin_p99_us @ttfb_origin_p99_us end |
#ttfb_shield_p25_us ⇒ Object
25th percentile of time to first byte from shield, in microseconds.
36 37 38 |
# File 'lib/fastly/models/platform_values.rb', line 36 def ttfb_shield_p25_us @ttfb_shield_p25_us end |
#ttfb_shield_p50_us ⇒ Object
50th percentile of time to first byte from shield, in microseconds.
39 40 41 |
# File 'lib/fastly/models/platform_values.rb', line 39 def ttfb_shield_p50_us @ttfb_shield_p50_us end |
#ttfb_shield_p75_us ⇒ Object
75th percentile of time to first byte from shield, in microseconds.
42 43 44 |
# File 'lib/fastly/models/platform_values.rb', line 42 def ttfb_shield_p75_us @ttfb_shield_p75_us end |
#ttfb_shield_p95_us ⇒ Object
95th percentile of time to first byte from shield, in microseconds.
45 46 47 |
# File 'lib/fastly/models/platform_values.rb', line 45 def ttfb_shield_p95_us @ttfb_shield_p95_us end |
#ttfb_shield_p99_us ⇒ Object
99th percentile of time to first byte from shield, in microseconds.
48 49 50 |
# File 'lib/fastly/models/platform_values.rb', line 48 def ttfb_shield_p99_us @ttfb_shield_p99_us end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/fastly/models/platform_values.rb', line 88 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/fastly/models/platform_values.rb', line 66 def self.attribute_map { :'timestamp' => :'timestamp', :'ttfb_origin_p25_us' => :'ttfb_origin_p25_us', :'ttfb_origin_p50_us' => :'ttfb_origin_p50_us', :'ttfb_origin_p75_us' => :'ttfb_origin_p75_us', :'ttfb_origin_p95_us' => :'ttfb_origin_p95_us', :'ttfb_origin_p99_us' => :'ttfb_origin_p99_us', :'ttfb_shield_p25_us' => :'ttfb_shield_p25_us', :'ttfb_shield_p50_us' => :'ttfb_shield_p50_us', :'ttfb_shield_p75_us' => :'ttfb_shield_p75_us', :'ttfb_shield_p95_us' => :'ttfb_shield_p95_us', :'ttfb_shield_p99_us' => :'ttfb_shield_p99_us', :'ttfb_edge_p25_us' => :'ttfb_edge_p25_us', :'ttfb_edge_p50_us' => :'ttfb_edge_p50_us', :'ttfb_edge_p75_us' => :'ttfb_edge_p75_us', :'ttfb_edge_p95_us' => :'ttfb_edge_p95_us', :'ttfb_edge_p99_us' => :'ttfb_edge_p99_us' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 |
# File 'lib/fastly/models/platform_values.rb', line 251 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.fastly_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/fastly/models/platform_values.rb', line 115 def self.fastly_nullable Set.new([ ]) end |
.fastly_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/fastly/models/platform_values.rb', line 93 def self.fastly_types { :'timestamp' => :'Time', :'ttfb_origin_p25_us' => :'Float', :'ttfb_origin_p50_us' => :'Float', :'ttfb_origin_p75_us' => :'Float', :'ttfb_origin_p95_us' => :'Float', :'ttfb_origin_p99_us' => :'Float', :'ttfb_shield_p25_us' => :'Float', :'ttfb_shield_p50_us' => :'Float', :'ttfb_shield_p75_us' => :'Float', :'ttfb_shield_p95_us' => :'Float', :'ttfb_shield_p99_us' => :'Float', :'ttfb_edge_p25_us' => :'Float', :'ttfb_edge_p50_us' => :'Float', :'ttfb_edge_p75_us' => :'Float', :'ttfb_edge_p95_us' => :'Float', :'ttfb_edge_p99_us' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/fastly/models/platform_values.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && ttfb_origin_p25_us == o.ttfb_origin_p25_us && ttfb_origin_p50_us == o.ttfb_origin_p50_us && ttfb_origin_p75_us == o.ttfb_origin_p75_us && ttfb_origin_p95_us == o.ttfb_origin_p95_us && ttfb_origin_p99_us == o.ttfb_origin_p99_us && ttfb_shield_p25_us == o.ttfb_shield_p25_us && ttfb_shield_p50_us == o.ttfb_shield_p50_us && ttfb_shield_p75_us == o.ttfb_shield_p75_us && ttfb_shield_p95_us == o.ttfb_shield_p95_us && ttfb_shield_p99_us == o.ttfb_shield_p99_us && ttfb_edge_p25_us == o.ttfb_edge_p25_us && ttfb_edge_p50_us == o.ttfb_edge_p50_us && ttfb_edge_p75_us == o.ttfb_edge_p75_us && ttfb_edge_p95_us == o.ttfb_edge_p95_us && ttfb_edge_p99_us == o.ttfb_edge_p99_us end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/fastly/models/platform_values.rb', line 281 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Fastly.const_get(type) klass.respond_to?(:fastly_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/fastly/models/platform_values.rb', line 352 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/fastly/models/platform_values.rb', line 258 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.fastly_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.fastly_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/fastly/models/platform_values.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/fastly/models/platform_values.rb', line 244 def hash [, ttfb_origin_p25_us, ttfb_origin_p50_us, ttfb_origin_p75_us, ttfb_origin_p95_us, ttfb_origin_p99_us, ttfb_shield_p25_us, ttfb_shield_p50_us, ttfb_shield_p75_us, ttfb_shield_p95_us, ttfb_shield_p99_us, ttfb_edge_p25_us, ttfb_edge_p50_us, ttfb_edge_p75_us, ttfb_edge_p95_us, ttfb_edge_p99_us].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 |
# File 'lib/fastly/models/platform_values.rb', line 202 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
328 329 330 |
# File 'lib/fastly/models/platform_values.rb', line 328 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/fastly/models/platform_values.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.fastly_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/fastly/models/platform_values.rb', line 322 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 |
# File 'lib/fastly/models/platform_values.rb', line 209 def valid? true end |