Class: Fastly::ProductDdosProtectionApi
- Inherits:
-
Object
- Object
- Fastly::ProductDdosProtectionApi
- Defined in:
- lib/fastly/api/product_ddos_protection_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#disable_product_ddos_protection(opts = {}) ⇒ nil
Disable product Disable the DDoS Protection product on a service.
-
#disable_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable product Disable the DDoS Protection product on a service.
-
#enable_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseEnable
Enable product Enable the DDoS Protection product on a service in default ‘log’ mode unless otherwise specified in the request body.
-
#enable_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseEnable, Integer, Hash)>
Enable product Enable the DDoS Protection product on a service in default 'log' mode unless otherwise specified in the request body.
-
#get_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseEnable
Get product enablement status Get the enablement status of the DDoS Protection product on a service.
-
#get_product_ddos_protection_configuration(opts = {}) ⇒ DdosProtectionResponseConfigure
Get configuration Get configuration of the DDoS Protection product on a service.
-
#get_product_ddos_protection_configuration_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseConfigure, Integer, Hash)>
Get configuration Get configuration of the DDoS Protection product on a service.
-
#get_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseEnable, Integer, Hash)>
Get product enablement status Get the enablement status of the DDoS Protection product on a service.
-
#get_services_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseBodyGetAllServices
Get services with product enabled Get all the services which have the DDoS Protection product enabled.
-
#get_services_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseBodyGetAllServices, Integer, Hash)>
Get services with product enabled Get all the services which have the DDoS Protection product enabled.
-
#initialize(api_client = ApiClient.default) ⇒ ProductDdosProtectionApi
constructor
A new instance of ProductDdosProtectionApi.
-
#set_product_ddos_protection_configuration(opts = {}) ⇒ DdosProtectionResponseConfigure
Update configuration Update configuration of the DDoS Protection product on a service.
-
#set_product_ddos_protection_configuration_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseConfigure, Integer, Hash)>
Update configuration Update configuration of the DDoS Protection product on a service.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProductDdosProtectionApi
Returns a new instance of ProductDdosProtectionApi.
17 18 19 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 17 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
15 16 17 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 15 def api_client @api_client end |
Instance Method Details
#disable_product_ddos_protection(opts = {}) ⇒ nil
Disable product Disable the DDoS Protection product on a service.
24 25 26 27 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 24 def disable_product_ddos_protection(opts = {}) disable_product_ddos_protection_with_http_info(opts) nil end |
#disable_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable product Disable the DDoS Protection product on a service.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 33 def disable_product_ddos_protection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.disable_product_ddos_protection ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling ProductDdosProtectionApi.disable_product_ddos_protection" end # resource path local_var_path = '/enabled-products/v1/ddos_protection/services/{service_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.disable_product_ddos_protection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#disable_product_ddos_protection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#enable_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseEnable
Enable product Enable the DDoS Protection product on a service in default ‘log’ mode unless otherwise specified in the request body.
86 87 88 89 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 86 def enable_product_ddos_protection(opts = {}) data, _status_code, _headers = enable_product_ddos_protection_with_http_info(opts) data end |
#enable_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseEnable, Integer, Hash)>
Enable product Enable the DDoS Protection product on a service in default 'log' mode unless otherwise specified in the request body.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 96 def enable_product_ddos_protection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.enable_product_ddos_protection ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling ProductDdosProtectionApi.enable_product_ddos_protection" end # resource path local_var_path = '/enabled-products/v1/ddos_protection/services/{service_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'ddos_protection_request_enable_mode']) # return_type return_type = opts[:debug_return_type] || 'DdosProtectionResponseEnable' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.enable_product_ddos_protection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#enable_product_ddos_protection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseEnable
Get product enablement status Get the enablement status of the DDoS Protection product on a service.
155 156 157 158 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 155 def get_product_ddos_protection(opts = {}) data, _status_code, _headers = get_product_ddos_protection_with_http_info(opts) data end |
#get_product_ddos_protection_configuration(opts = {}) ⇒ DdosProtectionResponseConfigure
Get configuration Get configuration of the DDoS Protection product on a service.
218 219 220 221 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 218 def get_product_ddos_protection_configuration(opts = {}) data, _status_code, _headers = get_product_ddos_protection_configuration_with_http_info(opts) data end |
#get_product_ddos_protection_configuration_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseConfigure, Integer, Hash)>
Get configuration Get configuration of the DDoS Protection product on a service.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 227 def get_product_ddos_protection_configuration_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.get_product_ddos_protection_configuration ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling ProductDdosProtectionApi.get_product_ddos_protection_configuration" end # resource path local_var_path = '/enabled-products/v1/ddos_protection/services/{service_id}/configuration'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DdosProtectionResponseConfigure' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.get_product_ddos_protection_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#get_product_ddos_protection_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseEnable, Integer, Hash)>
Get product enablement status Get the enablement status of the DDoS Protection product on a service.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 164 def get_product_ddos_protection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.get_product_ddos_protection ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling ProductDdosProtectionApi.get_product_ddos_protection" end # resource path local_var_path = '/enabled-products/v1/ddos_protection/services/{service_id}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DdosProtectionResponseEnable' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.get_product_ddos_protection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#get_product_ddos_protection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_services_product_ddos_protection(opts = {}) ⇒ DdosProtectionResponseBodyGetAllServices
Get services with product enabled Get all the services which have the DDoS Protection product enabled.
280 281 282 283 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 280 def get_services_product_ddos_protection(opts = {}) data, _status_code, _headers = get_services_product_ddos_protection_with_http_info(opts) data end |
#get_services_product_ddos_protection_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseBodyGetAllServices, Integer, Hash)>
Get services with product enabled Get all the services which have the DDoS Protection product enabled.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 288 def get_services_product_ddos_protection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.get_services_product_ddos_protection ...' end # unbox the parameters from the hash # resource path local_var_path = '/enabled-products/v1/ddos_protection/services' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DdosProtectionResponseBodyGetAllServices' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.get_services_product_ddos_protection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#get_services_product_ddos_protection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_product_ddos_protection_configuration(opts = {}) ⇒ DdosProtectionResponseConfigure
Update configuration Update configuration of the DDoS Protection product on a service.
338 339 340 341 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 338 def set_product_ddos_protection_configuration(opts = {}) data, _status_code, _headers = set_product_ddos_protection_configuration_with_http_info(opts) data end |
#set_product_ddos_protection_configuration_with_http_info(opts = {}) ⇒ Array<(DdosProtectionResponseConfigure, Integer, Hash)>
Update configuration Update configuration of the DDoS Protection product on a service.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/fastly/api/product_ddos_protection_api.rb', line 348 def set_product_ddos_protection_configuration_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDdosProtectionApi.set_product_ddos_protection_configuration ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling ProductDdosProtectionApi.set_product_ddos_protection_configuration" end # resource path local_var_path = '/enabled-products/v1/ddos_protection/services/{service_id}/configuration'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'ddos_protection_request_update_configuration']) # return_type return_type = opts[:debug_return_type] || 'DdosProtectionResponseConfigure' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDdosProtectionApi.set_product_ddos_protection_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDdosProtectionApi#set_product_ddos_protection_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |