Class: Fastly::ProductDomainResearchApi
- Inherits:
-
Object
- Object
- Fastly::ProductDomainResearchApi
- Defined in:
- lib/fastly/api/product_domain_research_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#disable_product_domain_research(opts = {}) ⇒ nil
Disable product Disable the Domain Research product.
-
#disable_product_domain_research_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable product Disable the Domain Research product.
-
#enable_domain_research(opts = {}) ⇒ DomainResearchResponseBodyEnable
Enable product Enable the Domain Research product.
-
#enable_domain_research_with_http_info(opts = {}) ⇒ Array<(DomainResearchResponseBodyEnable, Integer, Hash)>
Enable product Enable the Domain Research product.
-
#get_domain_research(opts = {}) ⇒ DomainResearchResponseBodyEnable
Get product enablement status Get the enablement status of the Domain Research product.
-
#get_domain_research_with_http_info(opts = {}) ⇒ Array<(DomainResearchResponseBodyEnable, Integer, Hash)>
Get product enablement status Get the enablement status of the Domain Research product.
-
#initialize(api_client = ApiClient.default) ⇒ ProductDomainResearchApi
constructor
A new instance of ProductDomainResearchApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProductDomainResearchApi
Returns a new instance of ProductDomainResearchApi.
17 18 19 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 17 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
15 16 17 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 15 def api_client @api_client end |
Instance Method Details
#disable_product_domain_research(opts = {}) ⇒ nil
Disable product Disable the Domain Research product.
23 24 25 26 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 23 def disable_product_domain_research(opts = {}) disable_product_domain_research_with_http_info(opts) nil end |
#disable_product_domain_research_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable product Disable the Domain Research product.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 31 def disable_product_domain_research_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDomainResearchApi.disable_product_domain_research ...' end # unbox the parameters from the hash # resource path local_var_path = '/enabled-products/v1/domain_research' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDomainResearchApi.disable_product_domain_research", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDomainResearchApi#disable_product_domain_research\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#enable_domain_research(opts = {}) ⇒ DomainResearchResponseBodyEnable
Enable product Enable the Domain Research product.
77 78 79 80 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 77 def enable_domain_research(opts = {}) data, _status_code, _headers = enable_domain_research_with_http_info(opts) data end |
#enable_domain_research_with_http_info(opts = {}) ⇒ Array<(DomainResearchResponseBodyEnable, Integer, Hash)>
Enable product Enable the Domain Research product.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 85 def enable_domain_research_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDomainResearchApi.enable_domain_research ...' end # unbox the parameters from the hash # resource path local_var_path = '/enabled-products/v1/domain_research' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainResearchResponseBodyEnable' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDomainResearchApi.enable_domain_research", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDomainResearchApi#enable_domain_research\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_domain_research(opts = {}) ⇒ DomainResearchResponseBodyEnable
Get product enablement status Get the enablement status of the Domain Research product.
133 134 135 136 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 133 def get_domain_research(opts = {}) data, _status_code, _headers = get_domain_research_with_http_info(opts) data end |
#get_domain_research_with_http_info(opts = {}) ⇒ Array<(DomainResearchResponseBodyEnable, Integer, Hash)>
Get product enablement status Get the enablement status of the Domain Research product.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/fastly/api/product_domain_research_api.rb', line 141 def get_domain_research_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductDomainResearchApi.get_domain_research ...' end # unbox the parameters from the hash # resource path local_var_path = '/enabled-products/v1/domain_research' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainResearchResponseBodyEnable' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"ProductDomainResearchApi.get_domain_research", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductDomainResearchApi#get_domain_research\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |