Class: Fastly::TokensApi
- Inherits:
-
Object
- Object
- Fastly::TokensApi
- Defined in:
- lib/fastly/api/tokens_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_token(opts = {}) ⇒ TokenResponse
Get a token Get a single token by its id.
-
#get_token_current(opts = {}) ⇒ TokenResponse
Get the current token Get a single token based on the access_token used in the request.
-
#get_token_current_with_http_info(opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Get the current token Get a single token based on the access_token used in the request.
-
#get_token_with_http_info(opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Get a token Get a single token by its id.
-
#initialize(api_client = ApiClient.default) ⇒ TokensApi
constructor
A new instance of TokensApi.
-
#list_tokens_customer(opts = {}) ⇒ Array<TokenResponse>
List tokens for a customer List all tokens belonging to a specific customer.
-
#list_tokens_customer_with_http_info(opts = {}) ⇒ Array<(Array<TokenResponse>, Integer, Hash)>
List tokens for a customer List all tokens belonging to a specific customer.
-
#list_tokens_user(opts = {}) ⇒ Array<TokenResponse>
List tokens for the authenticated user List all tokens belonging to the authenticated user.
-
#list_tokens_user_with_http_info(opts = {}) ⇒ Array<(Array<TokenResponse>, Integer, Hash)>
List tokens for the authenticated user List all tokens belonging to the authenticated user.
-
#revoke_token(opts = {}) ⇒ nil
Revoke a token Revoke a specific token by its id.
-
#revoke_token_current(opts = {}) ⇒ nil
Revoke the current token Revoke a token that is used to authenticate the request.
-
#revoke_token_current_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke the current token Revoke a token that is used to authenticate the request.
-
#revoke_token_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a token Revoke a specific token by its id.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
15 16 17 |
# File 'lib/fastly/api/tokens_api.rb', line 15 def api_client @api_client end |
Instance Method Details
#get_token(opts = {}) ⇒ TokenResponse
Get a token Get a single token by its id.
24 25 26 27 |
# File 'lib/fastly/api/tokens_api.rb', line 24 def get_token(opts = {}) data, _status_code, _headers = get_token_with_http_info(opts) data end |
#get_token_current(opts = {}) ⇒ TokenResponse
Get the current token Get a single token based on the access_token used in the request.
86 87 88 89 |
# File 'lib/fastly/api/tokens_api.rb', line 86 def get_token_current(opts = {}) data, _status_code, _headers = get_token_current_with_http_info(opts) data end |
#get_token_current_with_http_info(opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Get the current token Get a single token based on the access_token used in the request.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/fastly/api/tokens_api.rb', line 94 def get_token_current_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.get_token_current ...' end # unbox the parameters from the hash # resource path local_var_path = '/tokens/self' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.get_token_current", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#get_token_current\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_with_http_info(opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Get a token Get a single token by its id.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/fastly/api/tokens_api.rb', line 33 def get_token_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.get_token ...' end # unbox the parameters from the hash token_id = opts[:'token_id'] # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.get_token" end # resource path local_var_path = '/tokens/{token_id}'.sub('{' + 'token_id' + '}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.get_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#get_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_tokens_customer(opts = {}) ⇒ Array<TokenResponse>
List tokens for a customer List all tokens belonging to a specific customer.
143 144 145 146 |
# File 'lib/fastly/api/tokens_api.rb', line 143 def list_tokens_customer(opts = {}) data, _status_code, _headers = list_tokens_customer_with_http_info(opts) data end |
#list_tokens_customer_with_http_info(opts = {}) ⇒ Array<(Array<TokenResponse>, Integer, Hash)>
List tokens for a customer List all tokens belonging to a specific customer.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/fastly/api/tokens_api.rb', line 152 def list_tokens_customer_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.list_tokens_customer ...' end # unbox the parameters from the hash customer_id = opts[:'customer_id'] # verify the required parameter 'customer_id' is set if @api_client.config.client_side_validation && customer_id.nil? fail ArgumentError, "Missing the required parameter 'customer_id' when calling TokensApi.list_tokens_customer" end # resource path local_var_path = '/customer/{customer_id}/tokens'.sub('{' + 'customer_id' + '}', CGI.escape(customer_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<TokenResponse>' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.list_tokens_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#list_tokens_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_tokens_user(opts = {}) ⇒ Array<TokenResponse>
List tokens for the authenticated user List all tokens belonging to the authenticated user.
205 206 207 208 |
# File 'lib/fastly/api/tokens_api.rb', line 205 def list_tokens_user(opts = {}) data, _status_code, _headers = list_tokens_user_with_http_info(opts) data end |
#list_tokens_user_with_http_info(opts = {}) ⇒ Array<(Array<TokenResponse>, Integer, Hash)>
List tokens for the authenticated user List all tokens belonging to the authenticated user.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/fastly/api/tokens_api.rb', line 213 def list_tokens_user_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.list_tokens_user ...' end # unbox the parameters from the hash # resource path local_var_path = '/tokens' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<TokenResponse>' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.list_tokens_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#list_tokens_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_token(opts = {}) ⇒ nil
Revoke a token Revoke a specific token by its id.
262 263 264 265 |
# File 'lib/fastly/api/tokens_api.rb', line 262 def revoke_token(opts = {}) revoke_token_with_http_info(opts) nil end |
#revoke_token_current(opts = {}) ⇒ nil
Revoke the current token Revoke a token that is used to authenticate the request.
324 325 326 327 |
# File 'lib/fastly/api/tokens_api.rb', line 324 def revoke_token_current(opts = {}) revoke_token_current_with_http_info(opts) nil end |
#revoke_token_current_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke the current token Revoke a token that is used to authenticate the request.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/fastly/api/tokens_api.rb', line 332 def revoke_token_current_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.revoke_token_current ...' end # unbox the parameters from the hash # resource path local_var_path = '/tokens/self' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.revoke_token_current", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#revoke_token_current\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_token_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a token Revoke a specific token by its id.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/fastly/api/tokens_api.rb', line 271 def revoke_token_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.revoke_token ...' end # unbox the parameters from the hash token_id = opts[:'token_id'] # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.revoke_token" end # resource path local_var_path = '/tokens/{token_id}'.sub('{' + 'token_id' + '}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"TokensApi.revoke_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#revoke_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |