Class: Fastly::UserResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/fastly/models/user_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/fastly/models/user_response.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Fastly::UserResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Fastly::UserResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'login')
    self. = attributes[:'login']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'limit_services')
    self.limit_services = attributes[:'limit_services']
  end

  if attributes.key?(:'locked')
    self.locked = attributes[:'locked']
  end

  if attributes.key?(:'require_new_password')
    self.require_new_password = attributes[:'require_new_password']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'roles')
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
  end

  if attributes.key?(:'two_factor_auth_enabled')
    self.two_factor_auth_enabled = attributes[:'two_factor_auth_enabled']
  end

  if attributes.key?(:'two_factor_setup_required')
    self.two_factor_setup_required = attributes[:'two_factor_setup_required']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'email_hash')
    self.email_hash = attributes[:'email_hash']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end
end

Instance Attribute Details

#created_atObject

Date and time in ISO 8601 format.



42
43
44
# File 'lib/fastly/models/user_response.rb', line 42

def created_at
  @created_at
end

#customer_idObject

Returns the value of attribute customer_id.



55
56
57
# File 'lib/fastly/models/user_response.rb', line 55

def customer_id
  @customer_id
end

#deleted_atObject

Date and time in ISO 8601 format.



45
46
47
# File 'lib/fastly/models/user_response.rb', line 45

def deleted_at
  @deleted_at
end

#email_hashObject

The alphanumeric string identifying a email login.



53
54
55
# File 'lib/fastly/models/user_response.rb', line 53

def email_hash
  @email_hash
end

#idObject

Returns the value of attribute id.



50
51
52
# File 'lib/fastly/models/user_response.rb', line 50

def id
  @id
end

#limit_servicesObject

Indicates that the user has limited access to the customer’s services.



22
23
24
# File 'lib/fastly/models/user_response.rb', line 22

def limit_services
  @limit_services
end

#lockedObject

Indicates whether the is account is locked for editing or not.



25
26
27
# File 'lib/fastly/models/user_response.rb', line 25

def locked
  @locked
end

#loginObject

Returns the value of attribute login.



16
17
18
# File 'lib/fastly/models/user_response.rb', line 16

def 
  @login
end

#nameObject

The real life name of the user.



19
20
21
# File 'lib/fastly/models/user_response.rb', line 19

def name
  @name
end

#require_new_passwordObject

Indicates if a new password is required at next login.



28
29
30
# File 'lib/fastly/models/user_response.rb', line 28

def require_new_password
  @require_new_password
end

#roleObject

Returns the value of attribute role.



30
31
32
# File 'lib/fastly/models/user_response.rb', line 30

def role
  @role
end

#rolesObject

A list of role IDs assigned to the user.



33
34
35
# File 'lib/fastly/models/user_response.rb', line 33

def roles
  @roles
end

#two_factor_auth_enabledObject

Indicates if 2FA is enabled on the user.



36
37
38
# File 'lib/fastly/models/user_response.rb', line 36

def two_factor_auth_enabled
  @two_factor_auth_enabled
end

#two_factor_setup_requiredObject

Indicates if 2FA is required by the user’s customer account.



39
40
41
# File 'lib/fastly/models/user_response.rb', line 39

def two_factor_setup_required
  @two_factor_setup_required
end

#updated_atObject

Date and time in ISO 8601 format.



48
49
50
# File 'lib/fastly/models/user_response.rb', line 48

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/fastly/models/user_response.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/fastly/models/user_response.rb', line 58

def self.attribute_map
  {
    :'login' => :'login',
    :'name' => :'name',
    :'limit_services' => :'limit_services',
    :'locked' => :'locked',
    :'require_new_password' => :'require_new_password',
    :'role' => :'role',
    :'roles' => :'roles',
    :'two_factor_auth_enabled' => :'two_factor_auth_enabled',
    :'two_factor_setup_required' => :'two_factor_setup_required',
    :'created_at' => :'created_at',
    :'deleted_at' => :'deleted_at',
    :'updated_at' => :'updated_at',
    :'id' => :'id',
    :'email_hash' => :'email_hash',
    :'customer_id' => :'customer_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
# File 'lib/fastly/models/user_response.rb', line 253

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.fastly_all_ofObject

List of class defined in allOf (OpenAPI v3)



117
118
119
120
121
122
123
# File 'lib/fastly/models/user_response.rb', line 117

def self.fastly_all_of
  [
  :'Timestamps',
  :'User',
  :'UserResponseReadOnly'
  ]
end

.fastly_nullableObject

List of attributes with nullable: true



105
106
107
108
109
110
111
112
113
114
# File 'lib/fastly/models/user_response.rb', line 105

def self.fastly_nullable
  Set.new([
    :'locked',
    :'require_new_password',
    :'two_factor_auth_enabled',
    :'created_at',
    :'deleted_at',
    :'updated_at',
  ])
end

.fastly_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/fastly/models/user_response.rb', line 84

def self.fastly_types
  {
    :'login' => :'String',
    :'name' => :'String',
    :'limit_services' => :'Boolean',
    :'locked' => :'Boolean',
    :'require_new_password' => :'Boolean',
    :'role' => :'RoleUser',
    :'roles' => :'Array<String>',
    :'two_factor_auth_enabled' => :'Boolean',
    :'two_factor_setup_required' => :'Boolean',
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'updated_at' => :'Time',
    :'id' => :'String',
    :'email_hash' => :'String',
    :'customer_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/fastly/models/user_response.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      limit_services == o.limit_services &&
      locked == o.locked &&
      require_new_password == o.require_new_password &&
      role == o.role &&
      roles == o.roles &&
      two_factor_auth_enabled == o.two_factor_auth_enabled &&
      two_factor_setup_required == o.two_factor_setup_required &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      updated_at == o.updated_at &&
      id == o.id &&
      email_hash == o.email_hash &&
      customer_id == o.customer_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/fastly/models/user_response.rb', line 283

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Fastly.const_get(type)
    klass.respond_to?(:fastly_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/fastly/models/user_response.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/fastly/models/user_response.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.fastly_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.fastly_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/fastly/models/user_response.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/fastly/models/user_response.rb', line 246

def hash
  [, name, limit_services, locked, require_new_password, role, roles, two_factor_auth_enabled, two_factor_setup_required, created_at, deleted_at, updated_at, id, email_hash, customer_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
# File 'lib/fastly/models/user_response.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/fastly/models/user_response.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/fastly/models/user_response.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.fastly_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/fastly/models/user_response.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
# File 'lib/fastly/models/user_response.rb', line 212

def valid?
  true
end