Class: Fastly::MetricsPlatformApi
- Inherits:
-
Object
- Object
- Fastly::MetricsPlatformApi
- Defined in:
- lib/fastly/api/metrics_platform_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_platform_metrics_service_historical(opts = {}) ⇒ PlatformMetricsResponse
Get historical time series metrics for a single service Fetches historical metrics for a single service for a given granularity.
-
#get_platform_metrics_service_historical_with_http_info(opts = {}) ⇒ Array<(PlatformMetricsResponse, Integer, Hash)>
Get historical time series metrics for a single service Fetches historical metrics for a single service for a given granularity.
-
#initialize(api_client = ApiClient.default) ⇒ MetricsPlatformApi
constructor
A new instance of MetricsPlatformApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MetricsPlatformApi
Returns a new instance of MetricsPlatformApi.
17 18 19 |
# File 'lib/fastly/api/metrics_platform_api.rb', line 17 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
15 16 17 |
# File 'lib/fastly/api/metrics_platform_api.rb', line 15 def api_client @api_client end |
Instance Method Details
#get_platform_metrics_service_historical(opts = {}) ⇒ PlatformMetricsResponse
Get historical time series metrics for a single service Fetches historical metrics for a single service for a given granularity.
34 35 36 37 |
# File 'lib/fastly/api/metrics_platform_api.rb', line 34 def get_platform_metrics_service_historical(opts = {}) data, _status_code, _headers = get_platform_metrics_service_historical_with_http_info(opts) data end |
#get_platform_metrics_service_historical_with_http_info(opts = {}) ⇒ Array<(PlatformMetricsResponse, Integer, Hash)>
Get historical time series metrics for a single service Fetches historical metrics for a single service for a given granularity.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/fastly/api/metrics_platform_api.rb', line 53 def get_platform_metrics_service_historical_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetricsPlatformApi.get_platform_metrics_service_historical ...' end # unbox the parameters from the hash service_id = opts[:'service_id'] granularity = opts[:'granularity'] # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling MetricsPlatformApi.get_platform_metrics_service_historical" end # verify the required parameter 'granularity' is set if @api_client.config.client_side_validation && granularity.nil? fail ArgumentError, "Missing the required parameter 'granularity' when calling MetricsPlatformApi.get_platform_metrics_service_historical" end # verify enum value allowable_values = ["minutely", "hourly", "daily"] if @api_client.config.client_side_validation && !allowable_values.include?(granularity) fail ArgumentError, "invalid value for \"granularity\", must be one of #{allowable_values}" end allowable_values = ["ttfb"] if @api_client.config.client_side_validation && opts[:'metric_set'] && !allowable_values.include?(opts[:'metric_set']) fail ArgumentError, "invalid value for \"metric_set\", must be one of #{allowable_values}" end allowable_values = ["datacenter", "region"] if @api_client.config.client_side_validation && opts[:'group_by'] && !allowable_values.include?(opts[:'group_by']) fail ArgumentError, "invalid value for \"group_by\", must be one of #{allowable_values}" end allowable_values = ["africa_std", "anzac", "asia", "asia_india", "asia_southkorea", "europe", "mexico", "southamerica_std", "usa"] if @api_client.config.client_side_validation && opts[:'region'] && !allowable_values.include?(opts[:'region']) fail ArgumentError, "invalid value for \"region\", must be one of #{allowable_values}" end # resource path local_var_path = '/metrics/platform/services/{service_id}/{granularity}'.sub('{' + 'service_id' + '}', CGI.escape(service_id.to_s)).sub('{' + 'granularity' + '}', CGI.escape(granularity.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil? query_params[:'metric'] = opts[:'metric'] if !opts[:'metric'].nil? query_params[:'metric_set'] = opts[:'metric_set'] if !opts[:'metric_set'].nil? query_params[:'group_by'] = opts[:'group_by'] if !opts[:'group_by'].nil? query_params[:'region'] = opts[:'region'] if !opts[:'region'].nil? query_params[:'datacenter'] = opts[:'datacenter'] if !opts[:'datacenter'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlatformMetricsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"MetricsPlatformApi.get_platform_metrics_service_historical", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetricsPlatformApi#get_platform_metrics_service_historical\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |